PeriodicSyncConfig class

Configuration for periodic sync scheduling

Constructors

PeriodicSyncConfig({required int intervalSeconds, int? flexSeconds, bool? requiresNetwork, bool? requiresCharging, Map<String?, String?>? extras})

Properties

extras Map<String?, String?>?
getter/setter pair
flexSeconds int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
intervalSeconds int
getter/setter pair
requiresCharging bool?
getter/setter pair
requiresNetwork bool?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object result) PeriodicSyncConfig