SyncNetworkException class

Network failure during sync. Code range: 1200–1299.

Inheritance

Constructors

SyncNetworkException({required String message, int? errorCode = 1200})
const

Properties

details String?
finalinherited
errorCode int?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited