SyncStats class

Statistics from a completed sync operation.

Constructors

SyncStats({required int itemsUploaded, required int itemsDownloaded, required int conflicts, required int syncTimeMs})
const
SyncStats.fromData(SyncStatsData data)
factory

Properties

conflicts int
final
hashCode int
The hash code for this object.
no setterinherited
itemsDownloaded int
final
itemsUploaded int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
syncTimeMs int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited